==> hyades.source_3.2.0_20041101_1032.zip: org/eclipse/hyades/logging/events/cbe/impl/EventFactoryObjectFactory.java <==
package org.eclipse.hyades.logging.events.cbe.impl;

import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.util.Hashtable;

import javax.naming.BinaryRefAddr;
import javax.naming.Context;
import javax.naming.Name;
import javax.naming.RefAddr;
import javax.naming.Reference;
import javax.naming.spi.ObjectFactory;

import org.eclipse.hyades.logging.events.cbe.ContentHandler;
import org.eclipse.hyades.logging.events.cbe.EventException;
import org.eclipse.hyades.logging.events.cbe.util.EventHelpers;

/**********************************************************************
 * Copyright (c) 2004 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/

/**
 * JNDI object factory for <code>EventFactory</code> objects.
 * 
 * @author Denilson Nastacio
 * @version 1.0.1
 * @since 1.0.1
 * 
 * @see org.eclipse.hyades.logging.events.cbe.EventFactory
 */
public class EventFactoryObjectFactory implements ObjectFactory {

    /**
     * Classname for trace/log 
     */
    static final private String CLASS_NAME = EventFactoryObjectFactory.class.getName();

    /*
     * Public methods
     */

    /**
     * Simple constructor.
     */
    public EventFactoryObjectFactory() {
    }

    /**
     * @see javax.naming.spi.ObjectFactory#getObjectInstance(Object, Name, Context, Hashtable)
     */
    public Object getObjectInstance(Object obj, Name name, Context nameCtx, Hashtable environment) throws Exception {

        EventFactoryImpl result = null;

        if (obj instanceof Reference) {
            Reference ref = (Reference) obj;
            RefAddr refAddr = ref.get(EventFactoryImpl.CBE_INSTANCE_ADDRESS);
            if (refAddr instanceof BinaryRefAddr) {
                BinaryRefAddr binAddr = (BinaryRefAddr) refAddr;
                byte[] content = (byte[]) binAddr.getContent();
                try {
                    ByteArrayInputStream bis = new ByteArrayInputStream(content);
                    ObjectInputStream ois = new ObjectInputStream(bis);
                    ContentHandler mh = null;
                    try {
                        mh = (ContentHandler) ois.readObject();
                    }
                    finally {
                        ois.close();
                        bis.close();
                    }
                    result = new EventFactoryImpl();
                    result.setContentHandler(mh);
                }
                catch (IOException e) {
                    throw new EventException(EventHelpers.getString("LOG_FAILED_TO_DESERIALIZE_CONTENT_HANDLER_EXC_",name, e.getLocalizedMessage()));
                }
            }
            else {
                // Reference address is not binary
                throw new EventException(EventHelpers.getString("LOG_INVALID_JNDI_REFERENCE_EXC_",nameCtx.getNameInNamespace()));
            }
        }
        else {
            // Object is not a reference
            throw new EventException(EventHelpers.getString("LOG_INVALID_JNDI_REFERENCE_EXC_",nameCtx.getNameInNamespace()));
        } 

        return result;
    }
}

==> hyades.source_3.3.0_20050623_2150.zip: org/eclipse/hyades/logging/events/cbe/impl/EventFactoryObjectFactory.java <==
package org.eclipse.hyades.logging.events.cbe.impl;

import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.util.Hashtable;

import javax.naming.BinaryRefAddr;
import javax.naming.Context;
import javax.naming.Name;
import javax.naming.RefAddr;
import javax.naming.Reference;
import javax.naming.spi.ObjectFactory;

import org.eclipse.hyades.logging.events.cbe.ContentHandler;
import org.eclipse.hyades.logging.events.cbe.EventException;
import org.eclipse.hyades.logging.events.cbe.util.EventHelpers;

/**********************************************************************
 * Copyright (c) 2005 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * $Id: EventFactoryObjectFactory.java,v 1.8 2005/02/16 22:20:40 qiyanli Exp $
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/

/**
 * JNDI object factory for <code>EventFactory</code> objects.
 * 
 * @author Denilson Nastacio
 * @version 1.0.1
 * @since 1.0.1
 * 
 * @see org.eclipse.hyades.logging.events.cbe.EventFactory
 */
public class EventFactoryObjectFactory implements ObjectFactory {

    /**
     * Classname for trace/log 
     */
    static final private String CLASS_NAME = EventFactoryObjectFactory.class.getName();

    /*
     * Public methods
     */

    /**
     * Simple constructor.
     */
    public EventFactoryObjectFactory() {
    }

    /**
     * @see javax.naming.spi.ObjectFactory#getObjectInstance(Object, Name, Context, Hashtable)
     */
    public Object getObjectInstance(Object obj, Name name, Context nameCtx, Hashtable environment) throws Exception {

        EventFactoryImpl result = null;

        if (obj instanceof Reference) {
            Reference ref = (Reference) obj;
            RefAddr refAddr = ref.get(EventFactoryImpl.CBE_INSTANCE_ADDRESS);
            if (refAddr instanceof BinaryRefAddr) {
                BinaryRefAddr binAddr = (BinaryRefAddr) refAddr;
                byte[] content = (byte[]) binAddr.getContent();
                try {
                    ByteArrayInputStream bis = new ByteArrayInputStream(content);
                    ObjectInputStream ois = new ObjectInputStream(bis);
                    ContentHandler mh = null;
                    try {
                        mh = (ContentHandler) ois.readObject();
                    }
                    finally {
                        ois.close();
                        bis.close();
                    }
                    result = new EventFactoryImpl();
                    result.setContentHandler(mh);
                }
                catch (IOException e) {
                    throw new EventException(EventHelpers.getString("LOG_FAILED_TO_DESERIALIZE_CONTENT_HANDLER_EXC_",name, e.getLocalizedMessage()));
                }
            }
            else {
                // Reference address is not binary
                throw new EventException(EventHelpers.getString("LOG_INVALID_JNDI_REFERENCE_EXC_",nameCtx.getNameInNamespace()));
            }
        }
        else {
            // Object is not a reference
            throw new EventException(EventHelpers.getString("LOG_INVALID_JNDI_REFERENCE_EXC_",nameCtx.getNameInNamespace()));
        } 

        return result;
    }
}
